@@ -18,7 +18,7 @@ import json
 from datetime import timezone
 from datetime import datetime
 import gzip
-import zipfile
+# import zipfile
 import os
 import io
 import shutil
@@ -28,6 +28,7 @@ import logging
 
 import ftputil
 from secure_delete import secure_delete
+import patoolib
 import colemen_string_utils as strUtils
 import utils.dir as directory
 import utils.resources
@@ -49,6 +50,11 @@ logger = logging.getLogger(__name__)
 PILLOW_SUPPORTED_IMAGE_EXTENSIONS = ["bmp","dds","dib","eps","gif","icns","ico","im","jpg","jpeg","jpeg 2000","msp","pcx","png","ppm","sgi","spider","tga","tiff","webp","xbm"]
 GET_DATA_INCLUDE_DEFAULT_VALUE = ['file_name', 'extension', 'name_no_ext', 'dir_path', 'access_time', 'modified_time', 'created_time', 'size']
 
+
+
+
+
+
 def decompress(file_obj, compression="gzip"):
     '''
         Decompresses a file or list of files in place.
