@@ -25,6 +25,7 @@ def read(file_path, **kwargs):
         as_type = [as_type]
     read_as_json = objUtils.get_kwarg(['json', 'as json'], False, bool, **kwargs)
     read_to_array = objUtils.get_kwarg(['array', 'to_array'], False, bool, **kwargs)
+    read_to_data_array = objUtils.get_kwarg(['data_array'], False, bool, **kwargs)
     # data_array = objUtils.get_kwarg(['data array'], False, bool, **kwargs)
 
     if read_as_json is True:
@@ -32,6 +33,9 @@ def read(file_path, **kwargs):
 
     if read_to_array is True:
         return to_array(file_path)
+    
+    if read_to_data_array is True:
+        return data_array(file_path)
 
     if "duf" in as_type:
         return duf(file_path)
